@@ -7,7 +7,7 @@ use Types::Standard qw/Maybe/;
 use Types::Path::Tiny qw/Path/;
 use String::ShellQuote;
 
-our $VERSION = "0.08";
+our $VERSION = "0.09";
 
 =head1 NAME
 
@@ -19,7 +19,7 @@ Shell::Carapace - cpanm style logging for shell commands
 
     my $shell = Shell::Carapace->new(
         verbose => 1,                   # tee shell cmd output to STDOUT/STDERR
-        logfile => '/path/to/file.log', # log cmd output
+        logfile => '/path/to/file.log', # tee shell cmd output to logfile
     );
 
     my $output = $shell->local(@cmd);
@@ -96,25 +96,20 @@ sub local {
 
     return $self->_stringify(@cmd) if $self->noop;
 
-    my $merged_out;
-    my $exit;
+    my %args;
 
     if ($self->logfile) {
         my $cmd_str = $self->_stringify(@cmd);
         $self->logfile->touchpath;
         $self->logfile->append_utf8(">> $cmd_str\n");
 
-        ($merged_out, $exit) = $self->verbose
-            ? tee_merged     { system @cmd }
-            : capture_merged { system @cmd };
+        my $fh = $self->logfile->filehandle('+>>');
+        %args = (stdout => $fh);
+    }
 
-        $self->logfile->append_utf8($merged_out);
-    }
-    else {
-        ($merged_out, $exit) = $self->verbose
-            ? tee_merged     { system @cmd }
-            : capture_merged { system @cmd };
-    }
+    my ($merged_out, $exit) = $self->verbose
+        ? tee_merged     { system @cmd } %args
+        : capture_merged { system @cmd } %args;
 
     die "\n" if $exit;
 
@@ -133,14 +128,12 @@ sub _stringify {
 
 =over 4
 
+=item Capture::Tiny
+
 =item Shell::Cmd
 
-=item Capture::Tiny::Extended
-
 =item Net::OpenSSH
 
-=item Capture::Tiny
-
 =item IPC::System::Simple
 
 =back
